@@ -5,7 +5,7 @@ use File::Basename;
 use OptArgs2;
 use Path::Tiny;
 
-our $VERSION = '0.12.2';
+our $VERSION = '0.12.3';
 
 cmd 'App::githook::perltidy' => (
     name    => 'githook-perltidy',
@@ -188,20 +188,38 @@ sub sys {
       . $self->{me} . ': '
       . join( ' ', map { defined $_ ? $_ : '*UNDEF*' } @_ ) . "\n"
       if $self->{opts}->{verbose};
-    system("@_") == 0 or Carp::croak "@_ failed: $?";
+    system(@_) == 0 or Carp::croak "@_ failed: $?";
 }
 
 1;
 
+package App::githook_perltidy;
+
+our $VERSION = '0.12.3';
+
+1;
+
 __END__
 
 =head1 NAME
 
-App::githook::perltidy - OptArgs2 module for githook-perltidy.
+App::githook::perltidy - implementation guts of githook-perltidy.
+
+App::githook_perltidy - legacy package for dependencies
 
 =head1 VERSION
 
-0.12.2 (2018-09-25)
+0.12.3 (2018-11-22)
+
+=head1 DESCRIPTION
+
+The B<App::githook::perltidy> module contains the implementation of the
+L<githook-perltidy> script.
+
+The B<App::githook_perltidy> module only exists for backwards
+compatibility so that authors who have 'recommended' or 'required' it
+in a cpanfile or Makefile.PL or Build.PL get the new
+B<App::githook::perltidy> version.
 
 =head1 SEE ALSO
 
